cli

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2019 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Prompt string

Prompt specifies the prefix before each prompt

Functions

func HandleCommands

func HandleCommands(server *network.Server)

HandleCommands reads from standard input and handles the commands

func HideConsole

func HideConsole(showMessage bool)

func Writef

func Writef(format string, params ...interface{})

Writef formats the parameters and writes to standard output

func Writeln

func Writeln(params ...interface{})

Writeln writes to standard output with a newline

Types

This section is empty.

Jump to